# TCRUtils

Useful stuff for tcr projects.

TODO: Add here an index of best features

## Todo
  - [ ] ensure deps: apply f_back magic to automatically set global vars (instruct user)
  - [ ] finish imgui
    - [ ] add docstrings
  - [ ] finish execute
    - [ ] remove old execute
    - [ ] add docstrings
    - [ ] Placeholders
      - [ ] How to make your own placeholders template
      - Discord
        - Author
          - [x] mention / @ / @@
          - [x] username
          - [x] global name
          - [x] nickname
          - [x] discrim
          - [x] tag
          - [x] id
          - [x] isbot
          - [x] ishuman
          - [x] indms
          - [x] avatar
          - [x] roles
          - [ ] color
        - Server
          - [x] name
          - [x] id
          - [ ] members
          - [ ] roles
          - [ ] channels
          - [ ] categories
          - [ ] vcs
          - [ ] emojis
          - [ ] boosts
          - [ ] icon
        - [ ] 
        - [ ] Other
          - [x] attach (convert url to attachment)
      - Text
        - [ ] args
        - [x] var
        - [ ] Args
        - [ ] Variable with Arguments
        - [ ] Prefix
        - [ ] Alias
        - [ ] Test
        - [ ] Switch
        - [ ] Length
        - [ ] Lower
        - [ ] Upper
        - [ ] Capitalize
        - [ ] Apostrophe
        - [ ] Unmark
        - [ ] Reverse
        - [ ] Repeat
        - [ ] Limit
        - [ ] Slice
        - [ ] Split
        - [ ] Contains
        - [ ] URL
        - [ ] Spoiler
        - [ ] Replace
        - [ ] Regex
        - [ ] Regex Replace
        - [ ] Trim
        - [ ] Hex Color
        - [ ] Char
        - [ ] Char Code
        - [ ] Newline
        - [ ] comment
      - Math
        - [ ] RNG
        - [x] Add
        - [x] Subtract
        - [x] Multiply
        - [x] Divide
        - [x] Power
        - [x] Modulo
        - [x] Round
        - [x] Floor
        - [x] Ceil
        - [ ] Fixed
        - [ ] Precise
        - [ ] Highest
        - [ ] Lowest
        - [ ] Absolute
        - [ ] Clamp
        - [ ] Commafy
        - [ ] Nth
        - [ ] Bit
        - [ ] BBit
        - [ ] Base

~~<style>s{color: crimson;} b,strong{text-decoration:underline}</style>~~
<!-- I am MEGUMIN the greatest mage among crimson demons and wielder of EXPLOSION MAGIC -->
~~<style>p, li{font-family: "Hubot Sans Bold"; font-size: 17px}</style>~~
~~<style>code, pre{font-family: Consolas}</style>~~
~~<style>code{background-color: #271a45; border-radius: 4px; padding: 2px; padding-left: 5px; padding-right: 5px;}</style>~~
